function hh = errorbarxy(x, y, xe, ye, symbol, plotFun)
%ERRORBARXY Plot (x,y) data with error bars in both x and y directions.
%   ERRORBAR(X,Y,XE,YE) plots the graph of vector X vs. vector Y with
%   error bars specified by the columns of XE and YE.  XE and YE are
%   m-by-n matrices, where m is the number of elements in X and Y
%   (the number of data points) and n is either 1 or 2.  If n is 1,
%   error bars are drawn at X(i) +/- XE(i) and Y(i) +/- YE(i).
%   If n is 2, the the error bars are drawn from X(i) - XE(i,1) to
%   X(i) + XE(i,2) and Y(i) - YE(i,1) to Y(i) + YE(i,2).  In other
%   words, if XE and YE have only one column, the error bars are
%   symmetric.  If XE and YE have two columns, the error bars are
%   not symmetric.  The vectors X,Y,XE and YE must all have the same
%   number of rows.  Unlike the built-in errorbar function, X and Y
%   cannot be matrices (in the current implementation)
%
%   ERRORBAR(...,'LineSpec') uses the color and linestyle specified by
%   the string 'LineSpec'.  See PLOT for possibilities.
%
%   ERRORBAR(...,'LineSpec',plotFun) uses plotFun to create the graph.  This
%   feature allows log scaling of x or y or both axes.  Examples:  plotFun='loglog',
%   plotFun = 'semilogx', plotFun = 'plot' (Default), 
%
%   H = ERRORBAR(...) returns a vector of line handles.
%
%   For example,
%      x = 1:10;
%      y = sin(x);
%      e = std(y)*ones(size(x));
%      errorbar(x,y,e)
%   draws symmetric error bars of unit standard deviation.

%   Based on ERRORBAR, by L. Shure 5-17-88, 10-1-91 B.A. Jones 4-5-93
%   Copyright 1984-2001 The MathWorks, Inc. 
%   $Revision: 5.18 $  $Date: 2001/04/15 12:03:51 $
%   ERRORBARXY is by G. Recktenwald, 5-27-02, gerry@me.pdx.edu

if nargin<4, ye=xe;             end   % dubious: x and y error bars are equal
if nargin<5, symbol = '-';      end   % default line style for (x,y) data, not error bars
if nargin<6, plotFun = 'plot';  end

 % -- Check inputs: data must be numeric
if isstr(x) | isstr(y) | isstr(xe) | isstr(ye)
    error('Arguments must be numeric.')
end

% --- Make sure dimensions of input vectors and matrices are consistent
if ~isequal(size(x),size(y)) 
  error('X and Y must have the same number of rows and columns.');
elseif ~isequal(size(x,1),size(xe,1)) 
  error('X and XE must have the same numbers of rows.');
elseif  ~isequal(size(y,1),size(ye,1)),
  error('Y and YE must have the same numbers of rows.');
end

% --- Verify that x is a vector (X and Y have same size, see above)
if min(size(x))==1,
  npt = length(x);
  x = x(:);    %  convert inputs to column vectors
  y = y(:);
else
  error(sprintf('%s cannot handle matrix input for x',mfilename));
end

% --- Make sure error bars are real and positive
xe = abs(xe(:));
ye = abs(ye(:));
    
% --- Construct data for error bars
%      Vertical error bars extend from ybot to ytop, and have cross T's
%      that are +/- "tee" long.  xl and xr are extent of the cross T's.
%      Horizontal error bars extend from xleft to xright, and have cross
%      T's that are +/- "tee" long.  ybh and yth are extent of cross T's.

if strcmp('loglog',lower(plotFun)) | strcmp('semilogx',lower(plotFun))
  %  log axes compress/expand equal lengths.  Scale T's with x to get constant visual length
  tee = 0.01*x*log10(max(x(:))-min(x(:)));
else
  tee = (max(x(:))-min(x(:)))/100;  %  Make tee for linear scale, 0.02 of max(x)-xmin(x)
end
xl = x - tee;                     %  Begin vertical error bars
xr = x + tee;
if size(ye,2)>1        %  non-symmetric error bars
  ytop = y + ye(:,2);
  ybot = y - ye(:,1);
else                   %  symmetric
  ytop = y + ye(:);
  ybot = y - ye(:);
end
if strcmp('loglog',lower(plotFun)) | strcmp('semilogy',lower(plotFun))
  tee = 0.01*y*log10(max(y(:))-min(y(:)));
else
  tee = (max(y(:))-min(y(:)))/100;  %  Make T for linear scale, 0.02 of max(y)-xmin(y)
end
ybh = y - tee;                     %  Begin horizontal error bars
yth = y + tee;
if size(xe,2)>1        %  non-symmetric error bars
  xright = x + xe(:,2);
  xleft  = x - xe(:,1);
else                   %  symmetric
  xright = x + xe(:);
  xleft  = x - xe(:);
end

% --- Build up nan-separated vector for vertical bars
n = 1;                  %  n = size(y,2)  for original ERRORBAR, n = # of data sets
npt = length(x);
xb = zeros(npt*9,n);    %  n ~= 1 for original ERRORBAR
xb(1:9:end,:) = x;
xb(2:9:end,:) = x;
xb(3:9:end,:) = NaN;
xb(4:9:end,:) = xl;
xb(5:9:end,:) = xr;
xb(6:9:end,:) = NaN;
xb(7:9:end,:) = xl;
xb(8:9:end,:) = xr;
xb(9:9:end,:) = NaN;

yb = zeros(npt*9,n);
yb(1:9:end,:) = ytop;
yb(2:9:end,:) = ybot;
yb(3:9:end,:) = NaN;
yb(4:9:end,:) = ytop;
yb(5:9:end,:) = ytop;
yb(6:9:end,:) = NaN;
yb(7:9:end,:) = ybot;
yb(8:9:end,:) = ybot;
yb(9:9:end,:) = NaN;

% --- Build up nan-separated vector for horizontal bars
xbv = zeros(npt*9,n);
xbv(1:9:end,:) = xleft;
xbv(2:9:end,:) = xright;
xbv(3:9:end,:) = NaN;
xbv(4:9:end,:) = xleft;
xbv(5:9:end,:) = xleft;
xbv(6:9:end,:) = NaN;
xbv(7:9:end,:) = xright;
xbv(8:9:end,:) = xright;
xbv(9:9:end,:) = NaN;

ybv = zeros(npt*9,n);
ybv(1:9:end,:) = y;
ybv(2:9:end,:) = y;
ybv(3:9:end,:) = NaN;
ybv(4:9:end,:) = ybh;
ybv(5:9:end,:) = yth;
ybv(6:9:end,:) = NaN;
ybv(7:9:end,:) = ybh;
ybv(8:9:end,:) = yth;
ybv(9:9:end,:) = NaN;

% --- Figure out the linestyle, color, and marker specified by 'symbol'
[ls,col,mark,msg] = colstyle(symbol);  %  built-in function to parse linestyle
if ~isempty(msg), error(msg); end
symbol = [ls mark col];                %  Use marker only on data part
esymbol = ['-' col];                   %  Make sure bars are solid

% --- Prepar plot window
hold_state = ishold;   %  save so that 'hold on' or 'hold off' can be reset
cax = newplot;
next = lower(get(cax,'NextPlot'));

% --- Construct the plots, data first, then error bars
h = feval(plotFun,x,y,symbol);         hold on    %  data
h = [h; feval(plotFun,xb,yb,esymbol)];             %  vertical error bars
h = [h;feval(plotFun,xbv,ybv,esymbol)];           %  horizontal error bars

if ~hold_state, hold off; end

if nargout>0, hh = h; end