function [Q,dQ,dp,ddp] = flowBenchStats(patm,dpatm,dn,ddn,emf,demf,R,dR,vdpp,dVdpp,vdpn,dVdpn)
% flowBenchStats  Compute flow rate and plenum pressure drop from flow bench measurements.
%
% Synopsis: [Q,dQ,dp,ddp] = flowBenchStats(patm,dn,ddn,emf,demf,R,dR,vdpp,dVdpp,vdpn,dVdpn)
%
% Input:  patm  = atmospheric pressure,  Pa
%         dpatm = uncertainty in atmospheric pressure reading,  Pa
%         dn    = nozzle diameter, m
%         ddn   = uncertainty in nozzle diameter, m
%         emf   = emf of T-type thermocouple upstream of the flow nozzle, mV
%         demf  = uncertainty in emf due to random fluctuations, mV
%         R     = thermistor resistance,  Ohms
%         dR    = uncertainty of thermistor resistance due to random variations, Ohms
%         dvpp  = voltage output of transducer measuring the pressure between
%                ambient and the first plenum, V
%         dVdpp = uncertainty of dvpp due to random variations,  V
%         dvpn  = voltage output of transducer measuring the pressure difference
%                 across the nozzles, V
%         dVdpn = uncertainty of dvpn due to random variations,  V
%
% Output:  Q   = vector of flow rates, m^3/s
%          dQ  = vector of uncertainties for values in Q, m^3/s
%          dp  = vector of plenum pressure values (p-patm), Pa
%          ddp = vector of uncertainties for values in dp, Pa

verbose = true;           %  Flag to control printing: Set to false to turn off printing

% --- Routines for pressure transducer calibration:  change with transducers used 
dppFun = 'Omega05dp';     %  pressure drop between ambient and plenum
dpnFun = 'Omega10dp';     %  pressure drop across nozzles
dpcal = feval(dppFun);    %  calibration uncertainty for plenum pressure transducer
dpncal = feval(dpnFun);   %  calibration uncertainty for plenum pressure transducer

% --- Constants
dplen = 22*2.54e-2;   %  hydraulic diameter of plenum, m
dQcd = 0.005;         %  uncertainty in flow coefficient
dTcal = 0.2*5/9;      %  calibration uncertainty for tcouple wire (0.2 deg F at 200 F)

% --- Convert nominal data using calibration equations
dp = feval(dppFun,vdpp);            %  p_plenum - patm, Pa
p  = patm + dp;                     %  absolute p upstream of nozzle, Pa
dpn = feval(dpnFun,vdpn);           %  delta p across nozzle, Pa
T  = Ttemp(emf,thermistorT(R));     %  T upstream of nozzle, C

% --- Uncertainties in nozzle pressure measurements
dpnrand = feval(dpnFun,vdpn+dVdpn) - dpn;
ddpn  = sqrt(dpnrand.^2 + dpncal^2);

% --- Uncertainties in plenum pressure measurements
dprand = feval(dppFun,vdpp+dVdpp) - dp;
ddp = sqrt(dprand.^2 + dpcal^2);

% --- Uncertainties in temperature measurements
dTrandE = Ttemp(emf+demf,thermistorT(R)) - T;
dTrandR = Ttemp(emf,thermistorT(R+dR)) - T;
dT = sqrt(dTrandE.^2 + dTrandR.^2 + dTcal^2);  %  total uncertainty in T

% --- Loop over all data: compute nominal value, then perturb each input value
Q = zeros(length(dn),1);   dQ = Q;     %  preallocate: Q and dQ are filled with zeros
if verbose
  fprintf('\n  T (C)   p (Pa)   dp (Pa)  deldp (Pa) dpn (Pa)   Q (m^3/s)    dQ (m^3/s)\n');
end
for i=1:length(dn)
  Q(i) = nozzleFlow(dn(i),dplen,dpn(i),p(i),T(i));    % nominal flow rate
  % --- Perturb each input
  dQdn  = nozzleFlow(dn(i)+ddn, dplen, dpn(i),         p(i),       T(i))       - Q(i);
  dQdpn = nozzleFlow(dn(i),     dplen, dpn(i)+ddpn(i), p(i),       T(i))       - Q(i);
  dQdp  = nozzleFlow(dn(i),     dplen, dpn(i),         p(i)+dpatm, T(i))       - Q(i);
  dQT   = nozzleFlow(dn(i),     dplen, dpn(i),         p(i),       T(i)+dT(i)) - Q(i);
  % --- RSS combination of contributions to uncertainties
  dQ(i) = sqrt(dQdn^2 + dQdpn^2 + dQdp^2 + dQT^2 + (dQcd*Q(i))^2 );
  if verbose
    fprintf(' %6.2f  %8.1f %8.3f  %8.3f   %8.3f %12.4e %12.4e\n',...
      T(i),p(i),dp(i),ddp(i),dpn(i),Q(i),dQ(i));      
  end
end
