function d = loadFBStatsData(fname,verbose)
% loadFBstatsData  Load flow bench data from MAT file created by flowBenchDataSelector
%
% Syntax: d = loadFBStatsData(fname)
%         d = loadFBStatsData(fname,verbose)
%
% Input:  fname = name of MAT file containing averaged daa
%         verbose = flag to control printing of raw data
%
% Output: d = struct containing the following fields
%         d.dn = nozzle diameter
%         d.emf = average emf of thermocouple upstream of active nozzle (V)
%         d.emfstd = standard deviation of "  "  "   "  (V)
%         d.rt = average resistance of thermistor in zone box (ohm)
%         d.rtstd = standard deviation of "   "   "
%         d.vpp = average voltage of pressure transducer for upstream plenum
%         d.vppstd = standard deviation of "  "   "
%         d.vpn = average voltage of pressure transducer for flow nozzle
%         d.vpnstd = standard deviation of "  "   "

if nargin<2, verbose=false;  end

% --- Read contents of MAT file and assign to data struct
try
  load(fname);
catch
  error(sprintf('Could not load %s',fname));
end
d.dn = dn;
d.rt  = abs(R104ave);   %  Agilent returns negative resistance in 4-wire mode
d.rtstd  = R104std;
d.vpp = V105ave;     d.vppstd = V105std;
d.vpn = V106ave;     d.vpnstd = V106std;

% --- Thermocouple depends on size of nozzle
d.emf = zeros(size(V101ave));    d.emfstd = d.emf;   %  preallocate
for i=1:length(V101ave)
  switch nid(i)
    case 1
      d.emf(i) = V101ave(i);   d.emfstd(i) = V101std(i);
    case 2
      d.emf(i) = V102ave(i);   d.emfstd(i) = V102std(i);
    case 3
      d.emf(i) = V103ave(i);   d.emfstd(i) = V103std(i);
    otherwise
      error(sprintf('nid = %g  not allowed',nid(i)));
  end
end

if (verbose)
  % --- Print table of raw data
  fprintf('\nData for %s:\n',fname);
  fprintf('\n    dn       emf       vdpp      vdpn\n');
  fprintf('   (cm)      (mv)      (V)       (V)\n');
  for i=1:length(dn)
    fprintf('%8.4f  %8.4f  %8.4f  %8.4f\n',d.dn(i)*100,d.emf(i)*1000,d.vpp(i),d.vpn(i));
  end
end