function singleBlockPlots(fname)
% singleBlockPlots  Plot temperature versus time for the single block experiment
%
% Synopsis:  singleBlockPlots
%            singleBlockPlots(fname)
%
% Input:  fname = (string) name of file containing the data.  If fname is
%                 not supplied, the user is given a dialog box to specify
%                 the file to be read

if nargin<1
  v = makeVarAgilentData;
else
  v = makeVarAgilentData(fname);
end

% --- Convert temperatures
t = v.t;
Rz = abs(v.OHM101);  Tz = thermistorT(Rz);
T102 = Ttemp(v.VDC102,Tz);
T106 = Ttemp(v.VDC106,Tz);
T107 = Ttemp(v.VDC107,Tz);
T108 = Ttemp(v.VDC108,Tz);
T109 = Ttemp(v.VDC109,Tz);
T110 = Ttemp(v.VDC110,Tz);
T112 = Ttemp(v.VDC112,Tz);
T113 = Ttemp(v.VDC113,Tz);
T114 = Ttemp(v.VDC114,Tz);
T115 = Ttemp(v.VDC115,Tz);
T116 = Ttemp(v.VDC116,Tz);
T117 = Ttemp(v.VDC117,Tz);

f = figure;
set(f,'Name','Air and wall temperature')
plot(t,T102,'.',t,T112,':');  xlabel('t (s)');  ylabel('T  (C)');
legend('T_{air} = T_{102}','T_{wall} = T_{112}','Location','southeast');

f = figure;
set(f,'Name','Surface and inner T of top block')
plot(t,T106,'.',t,T108,':');  xlabel('t (s)');  ylabel('T  (C)');
legend('T_s = T_{106}','T_{top,i} = T_{108}','Location','southeast');

f = figure;
set(f,'Name','Top surface of bottom block')
plot(t,T107,'.',t,T109,':',t,0.5*(T107+T109),'--');
xlabel('t (s)');  ylabel('T  (C)');
legend('T_{bot,i,1} = T_{107}','T_{bot,i,2} = T_{109}',...
       'T_{b,i,ave}','Location','southeast');

f = figure;
set(f,'Name','Top surface of balsa')
plot(t,T110,'.',t,T113,':',t,0.5*(T110+T113),'--');
xlabel('t (s)');  ylabel('T  (C)');
legend('T_{balsa top,1} = T_{110}','T_{balsa top,2} = T_{113}',...
       'T_{balsa top,ave}','Location','southeast');

f = figure;
set(f,'Name','Bottom surface of balsa')
plot(t,T116,'.',t,T117,':',t,0.5*(T116+T117),'--');
xlabel('t (s)');  ylabel('T  (C)');
legend('T_{balsa bottom,1} = T_{116}','T_{balsa bottom,2} = T_{117}',...
       'T_{balsa bottom,ave}','Location','southeast');

f = figure;
set(f,'Name','Bottom surface simulated PCB')
plot(t,T114,'.',t,T115,':',t,0.5*(T114+T115),'--');
xlabel('t (s)');  ylabel('T  (C)');
legend('T_{PCB,1} = T_{114}','T_{PCB,2} = T_{117}','T_{PCB,ave}','Location','southeast');

% --- Compute input power and estimate of conduction loss
Rsh = 0.0065;
Ein = (v.VDC103).*(v.VDC104)/Rsh;
tbalsa = 2.54e-2*(1/8);    %  1/8 inch thick
kbalsa = 0.055;            %  conductivity (W/m/K)  Table A.1 in Incropera & DeWitt
Lblock = 2.54e-2*2;        %  length of one side of balsa block, (m)
Ablock = Lblock^2;
Tbtop = 0.5*(T110 + T113);
Tbbot = 0.5*(T116 + T117);
Qbalsa = kbalsa*Ablock*(Tbtop-Tbbot)/tbalsa;
sigma = 5.670e-8;             %  Stefan-Boltzmann constant
epsilon = 0.8;                %  Emissivity of Alumnium (estimated)
Qrad = sigma*epsilon*Ablock*( (T106+273.15).^4 - (T112+273.15).^4 );
klead = 393;                  %  conductivity of pure copper,  W/m/K
dlead = 0.5106e-3;            %  diameter of 24 gage wire;
Llead = 3*2.54e-2;            %  length of lead between Th and ambient
Th = (T108 + T109 + T107)/3;  %  average heater temperature
Rlead = 0.5*(Llead/ (klead*(0.25*pi*dlead^2) ) );
Qlead = (Th - T102)/Rlead;
f = figure;
set(f,'Name','Heat flows')
Qconv = Ein - Qbalsa - Qrad - Qlead;
plot(t,Ein,':',t,Qbalsa,'--',t,Qrad,'-.',t,Qlead,'.',t,Qconv,'-');
xlabel('t  (s)');    ylabel('Q  (W)');
legend('E_{in}','Q_{balsa}','Q_{rad}','Q_{lead}','Q_{conv}','Location','southeast');

if exist(fname,'var')
  fprintf('\nData from %s\n',fname);
end
fprintf('\n     Ein    Qbalsa      Qrad     Qlead     Qconv\n');
fprintf('%8.2f  %8.2f  %8.2f  %8.2f  %8.2f\n',...
        mean(Ein(end-25:end)),mean(Qbalsa(end-25:end)),mean(Qrad(end-25:end)),...
        mean(Qlead(end-25:end)),mean(Qconv(end-25:end)));
